@@ -16,7 +16,6 @@ prior_terminal_node_coef <- function(range = c(0, 1), trans = NULL) {
     range = range,
     inclusive = c(FALSE, TRUE),
     trans = trans,
-    default = 0.95,
     label = c(prior_terminal_node_coef = "Terminal Node Prior Coefficient"),
     finalize = NULL
   )
@@ -24,13 +23,12 @@ prior_terminal_node_coef <- function(range = c(0, 1), trans = NULL) {
 
 #' @rdname bart-param
 #' @export
-prior_terminal_node_expo <- function(range = c(0, 3), trans = NULL) {
+prior_terminal_node_expo <- function(range = c(1, 3), trans = NULL) {
   new_quant_param(
     type = "double",
     range = range,
-    inclusive = c(TRUE, TRUE),
+    inclusive = c(FALSE, TRUE),
     trans = trans,
-    default = 2.0,
     label = c(prior_terminal_node_expo = "Terminal Node Prior Exponent"),
     finalize = NULL
   )
@@ -44,7 +42,6 @@ prior_outcome_range <- function(range = c(0, 5), trans = NULL) {
     range = range,
     inclusive = c(FALSE, TRUE),
     trans = trans,
-    default = 2.0,
     label = c(prior_outcome_range = "Prior for Outcome Range"),
     finalize = NULL
   )
